pub fn delete_session(session: &SessionName) -> Result<SessionDeleteOutcome>Expand description
Delete a muxr session selected from the local picker.
Errors
- The session paths cannot be resolved.
- A live session accepts delete but does not stop and remove its files in time.
- The session files cannot be removed.